JobCubitState<T, F> class

Constructors

JobCubitState({required F data, JobState state = JobState.init, String message = ''})
const

Properties

builtData → JobCubitState<F, T>
no setter
data → F
final
hashCode → int
The hash code for this object.
no setterinherited
isFailed → bool
no setter
isInProgress → bool
no setter
isNotFailed → bool
no setter
isNotInProgress → bool
no setter
isNotReady → bool
no setter
isNotSuccess → bool
no setter
isReady → bool
no setter
isSuccess → bool
no setter
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → JobState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toButtonState({HubbleButtonState? defaultValue, HubbleButtonState? successValue, HubbleButtonState? errorValue}) → HubbleButtonState
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited