JobResult<T> class

Constructors

JobResult(bool isSuccess, {required T data, required String errorMessage})

Properties

data → T
final
errorMessage → String
final
hashCode → int
The hash code for this object.
no setterinherited
isFailed → bool
no setter
isSuccess → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited