HubbleForm class

Constructors

HubbleForm({required List<HubbleFormField> fields})

Properties

fields → List<HubbleFormField>
final
firstErrorMessage → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
isValid → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableAllFields() → void
enableAllFields() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showAllErrors() → void
toString() → String
A string representation of this object.
inherited
validate() → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited