ValueAndErrorMessage<T, E> class

Constructors

ValueAndErrorMessage({required T value, required E? validator(T value), bool isVisible = false, bool isEnabled = true, void onChanged(T value)?})

Properties

error → E?
latefinal
hashCode → int
The hash code for this object.
no setterinherited
isEnabled → bool
final
isValid → bool
no setter
isVisible → bool
final
onChanged → void Function(T value)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → T
final
visibleError → E?
no setter

Methods

copyWith({T? value, E? validator(T value)?, bool? isVisible, bool? isEnabled, void onChanged(T value)?}) → ValueAndErrorMessage<T, E>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited