IWidgetsRepo class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getContext(
{required String contextId}) → Future< Result< Map< >String, String> > -
getJson(
{required String resId}) → Future< Result< Map< >String, dynamic> > -
getMarkdown(
{required String resId}) → Future< Result< String> > -
getPage(
{required String pageId, required Map< String, String> offset, String? customBaseUrl}) → Future<Result< WidgetPage> > -
getWidget(
{required String widgetId, required Map< String, String> params, String? customBaseUrl}) → Future<Result< XWidget> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited