NativeCheckerBackground class

Inheritance

Constructors

NativeCheckerBackground({required Size boxSize, HubbleColor? color, HubbleColor? backgroundColor, HubbleGradient? gradient, HubbleGradient? backgroundGradient, double strokeWidth = 0, double verticalPadding = 0, double horizontalPadding = 0})
NativeCheckerBackground.from(NativeWidgetParams widget)
factory

Properties

backgroundColor → HubbleColor?
final
backgroundGradient → HubbleGradient?
final
boxSize → Size
final
color → HubbleColor?
final
gradient → HubbleGradient?
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalPadding → double
final
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
final
verticalPadding → double
final

Methods

applyTheme(HubbleThemeData theme) → void
inherited
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited