PaginatedView<T, V> class

Inheritance
Available extensions

Constructors

PaginatedView.grid({Key? key, Axis? scrollDirection, double? itemExtent, Clip? clipBehavior, bool? shrinkWrap, bool? reverse, bool? addAutomaticKeepAlive, bool? addRepaintBoundaries, bool? addSemanticIndexes, bool? primary, double? cacheExtent = 1000, String? restorationId, EdgeInsets? padding, Widget noItemsFoundIndicatorBuilder(BuildContext)?, bool animateTransitions = false, required PaginatedViewController<T, V> state, required Widget itemBuilder(T data, int index), required int crossAxisCount, required double childAspectRatio, double crossAxisSpacing = 0, double mainAxisSpacing = 0, double? mainAxisExtent, ScrollController? scrollController, bool noConstraints = true, List<Widget> footers = const [], List<Widget> headers = const [], double pageFetchThreshold = 1000})
const
PaginatedView.list({Key? key, Axis? scrollDirection, double? itemExtent, Clip? clipBehavior, bool? shrinkWrap, bool? reverse, bool? addAutomaticKeepAlive, bool? addRepaintBoundaries, bool? addSemanticIndexes, bool? primary, double? cacheExtent = 1000, String? restorationId, EdgeInsets? padding, ScrollController? scrollController, required Widget itemBuilder(T data, int index), required PaginatedViewController<T, V> state, Widget noItemsFoundIndicatorBuilder(BuildContext)?, bool animateTransitions = false, bool noConstraints = true, List<Widget> footers = const [], List<Widget> headers = const [], double pageFetchThreshold = 1000})
const
PaginatedView.sliverGrid({Key? key, Axis? scrollDirection, double? itemExtent, Clip? clipBehavior, bool? shrinkWrap, bool? reverse, bool? addAutomaticKeepAlive, bool? addRepaintBoundaries, bool? addSemanticIndexes, bool? primary, double? cacheExtent = 1000, String? restorationId, EdgeInsets? padding, required ScrollController scrollController, Widget noItemsFoundIndicatorBuilder(BuildContext)?, bool animateTransitions = false, required PaginatedViewController<T, V> state, required Widget itemBuilder(T data, int index), required int crossAxisCount, required double childAspectRatio, double crossAxisSpacing = 0, double mainAxisSpacing = 0, double? mainAxisExtent, bool noConstraints = true, List<Widget> footers = const [], List<Widget> headers = const [], double pageFetchThreshold = 1000})
const
PaginatedView.sliverList({Key? key, Axis? scrollDirection, double? itemExtent, Clip? clipBehavior, bool? shrinkWrap, bool? reverse, bool? addAutomaticKeepAlive, bool? addRepaintBoundaries, bool? addSemanticIndexes, bool? primary, double? cacheExtent = 1000, String? restorationId, EdgeInsets? padding, required ScrollController scrollController, required Widget itemBuilder(T data, int index), required PaginatedViewController<T, V> state, Widget noItemsFoundIndicatorBuilder(BuildContext)?, bool animateTransitions = false, bool noConstraints = true, List<Widget> footers = const [], List<Widget> headers = const [], double pageFetchThreshold = 1000})
const

Properties

addAutomaticKeepAlive → bool?
final
addRepaintBoundaries → bool?
final
addSemanticIndexes → bool?
final
animateTransitions → bool
final
cacheExtent → double?
final
childAspectRatio → double
final
clipBehavior → Clip?
final
crossAxisCount → int
final
crossAxisSpacing → double
final
footers → List<Widget>
final
hashCode → int
The hash code for this object.
no setterinherited
headers → List<Widget>
final
isGrid → bool
final
isSliver → bool
final
itemBuilder → Widget Function(T data, int index)
final
itemExtent → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisExtent → double?
final
mainAxisSpacing → double
final
noConstraints → bool
final
noItemsFoundIndicatorBuilder → Widget Function(BuildContext)?
final
padding → EdgeInsets?
final
pageFetchThreshold → double
final
primary → bool?
final
restorationId → String?
final
reverse → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
final
scrollDirection → Axis?
final
shrinkWrap → bool?
final
state → PaginatedViewController<T, V>
final

Methods

center({Key? key}) → Center

Available on Widget, provided by the WidgetHelperExtensionMethods extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<PaginatedView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
enlarge() → Transform

Available on Widget, provided by the WidgetHelperExtensionMethods extension

expanded({Key? key, int flex = 1}) → Expanded

Available on Widget, provided by the WidgetHelperExtensionMethods extension

fadeInSlideUp({int? nextRunDelay, AnimationIntervalController? intervalController}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

hubbleAnimate({int? nextRunDelay, AnimationIntervalController? intervalController, List<Effect>? effects}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pad(EdgeInsetsGeometry padding, {Key? key}) → Padding

Available on Widget, provided by the WidgetHelperExtensionMethods extension

padOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Padding

Available on Widget, provided by the WidgetHelperExtensionMethods extension

positioned({Key? key, double? left, double? top, double? right, double? bottom, double? width, double? height}) → Positioned

Available on Widget, provided by the WidgetHelperExtensionMethods extension

positionedFill({Key? key}) → Positioned

Available on Widget, provided by the WidgetHelperExtensionMethods extension

sizeTransition({AlignmentGeometry? alignment}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
transformScale({Key? key, double scale = 1.0, AlignmentGeometry alignment = Alignment.center}) → Transform

Available on Widget, provided by the WidgetHelperExtensionMethods extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited