PaginatedViewController<T, V> class

Inheritance

Constructors

PaginatedViewController({required Future<PageListChunk<T, V>> pageFetcher(V offset), required V initialOffset, int invisibleItemsThreshold = 15})

Properties

hashCode → int
The hash code for this object.
no setterinherited
initializer → DeferredJob<PaginatedViewState<T, V>>
latefinalinherited
initialOffset → V
final
invisibleItemsThreshold → int
final
isClosed → bool
Whether the bloc is closed.
no setterinherited
isInitialized → bool
no setterinherited
listable → ValueListenable<HubbleViewState>
no setterinherited
pageFetcher → Future<PageListChunk<T, V>> Function(V offset)
final
pageFetchJob → DeferredJob<PageListChunk<T, V>>
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snack → HubbleSnackBarState
no setterinherited
state → SimpleValue<HubbleViewState>
The current state.
no setterinherited
stream → Stream<SimpleValue<HubbleViewState>>
The current stream of states.
no setterinherited
value ↔ HubbleViewState
getter/setter pairinherited
viewState → PaginatedViewState<T, V>
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
appendLastPage(List<PageListItem<T>> items) → void
appendPage(List<PageListItem<T>> items, V? nextOffset) → void
build(Widget builder(BuildContext context, HubbleViewState value), {bool when(HubbleViewState, HubbleViewState)?}) → Widget
inherited
buildAs<Z>(Widget builder(BuildContext context, Z value), {bool when(HubbleViewState, HubbleViewState)?}) → Widget
inherited
buildIfNotEqual(Widget builder(BuildContext context, HubbleViewState value)) → Widget
inherited
close() → Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
defer<X>(dynamic object, void callback(X object)) → void
inherited
deferredScrollController({bool keepScrollOffset = true, double initialScrollOffset = 0.0}) → ScrollController
inherited
deferStream(StreamSubscription subscription) → void
inherited
emit(SimpleValue<HubbleViewState> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
fromContext(BuildContext context, {bool listen = true}) → SimpleValueCubit<HubbleViewState>
inherited
hydrate() → Future<void>
inherited
hydrateHeadless() → Future<PaginatedViewState<T, V>>
inherited
init() → Future<PaginatedViewState<T, V>>
override
inject<Injectable extends Object>() → Injectable
inherited
maybePop({Object? result}) → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAfterInit() → void
inherited
onChange(Change<SimpleValue<HubbleViewState>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
onInitFailure() → void
inherited
reactive<F>(F initialValue) → SimpleValueCubit<F>
inherited
refresh() → void
reInit() → void
inherited
setValue(HubbleViewState value) → void
inherited
showInModal<ModalResult>(WidgetBuilder builder, {required String routeName, Map<String, dynamic>? eventProps, bool expand = false}) → Future<ModalResult?>
inherited
softReInit() → Future<PaginatedViewState<T, V>>
inherited
toString() → String
A string representation of this object.
inherited
update(HubbleViewState predicate(HubbleViewState value)) → void
inherited
updateViewState(PaginatedViewState<T, V> predicate(PaginatedViewState<T, V> value)) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited