SimpleButtonProxyMarkdownViewBuilder class

Inheritance

Constructors

SimpleButtonProxyMarkdownViewBuilder({required VoidCallback onClick, required String buttonText, required String filePath})
const

Properties

buttonText → String
final
filePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
onClick → VoidCallback
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
view(BuildContext context) → Widget
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited