AppStyleBase class

Implementers

Constructors

AppStyleBase()

Properties

backButton → Color
no setter
background → Color
no setter
backgroundColor → Color
no setter
baseHorizontalPadding → EdgeInsets
no setter
basePadding → EdgeInsets
no setter
basePadding2x → EdgeInsets
no setter
baseVerticalPadding → EdgeInsets
no setter
borderRadiusLarge → BorderRadius
no setter
caption → TextStyle
no setter
cGrayABABAB → Color
no setter
defaultPadding → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
headline2 → TextStyle
no setter
iconOuterSize → double
no setter
iconSize → double
no setter
paddingSmall → EdgeInsets
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeLarge → double
no setter
sizeMedium → double
no setter
subtitle1 → TextStyle
no setter
surface → Color
no setter
t10Bold12 → TextStyle
no setter
t10Bold16 → TextStyle
no setter
t11Bold13 → TextStyle
no setter
t11Bold16 → TextStyle
no setter
t12Normal15 → TextStyle
no setter
t12Normal20 → TextStyle
no setter
t13Normal15 → TextStyle
no setter
t13Normal20 → TextStyle
no setter
t1550024 → TextStyle
no setter
t15Bold18 → TextStyle
no setter
t15Normal24 → TextStyle
no setter
t16Normal18 → TextStyle
no setter
t16Normal24 → TextStyle
no setter
t19Bold22 → TextStyle
no setter
t19Bold30 → TextStyle
no setter
t19Normal22 → TextStyle
no setter
t23Bold36 → TextStyle
no setter
t24Bold28 → TextStyle
no setter
t24Bold33 → TextStyle
no setter
t24Bold38 → TextStyle
no setter
t33Bold39 → TextStyle
no setter
t33Bold46 → TextStyle
no setter
t40bold48 → TextStyle
no setter
theme ↔ HubbleTheme
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited