CustomTextField class

Inheritance
Available extensions

Constructors

CustomTextField({Key? key, required TextEditingController textEditingController, String? label, TextInputType? textInputType, bool? readOnly, bool? autofocus, TextStyle? textStyle, bool? enabled, String? validator(String?)?, String? hintText, TextStyle? hintTextStyle, TextCapitalization textCapitalization = TextCapitalization.characters, int? maxLines, bool showCounter = false, TextStyle? counterStyle, int? maxLength, Widget? suffix, Pattern? pattern, bool wrapCustomBorder = false, String? errorText, EdgeInsets? padding, FocusNode? focusNode, TextStyle? labelStyle, void onChanged(String)?, bool obscureText = false, String obscuringCharacter = '•'})
const

Properties

autofocus → bool?
final
counterStyle → TextStyle?
final
enabled → bool?
final
errorText → String?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
hintTextStyle → TextStyle?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
final
labelStyle → TextStyle?
final
maxLength → int?
final
maxLines → int?
final
obscureText → bool
final
obscuringCharacter → String
final
onChanged → void Function(String)?
final
padding → EdgeInsets?
final
pattern → Pattern?
final
readOnly → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCounter → bool
final
suffix → Widget?
final
textCapitalization → TextCapitalization
final
textEditingController → TextEditingController
final
textInputType → TextInputType?
final
textStyle → TextStyle?
final
validator → String? Function(String?)?
final
wrapCustomBorder → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
center({Key? key}) → Center

Available on Widget, provided by the WidgetHelperExtensionMethods extension

createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
enlarge() → Transform

Available on Widget, provided by the WidgetHelperExtensionMethods extension

expanded({Key? key, int flex = 1}) → Expanded

Available on Widget, provided by the WidgetHelperExtensionMethods extension

fadeInSlideUp({int? nextRunDelay, AnimationIntervalController? intervalController}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

hubbleAnimate({int? nextRunDelay, AnimationIntervalController? intervalController, List<Effect>? effects}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pad(EdgeInsetsGeometry padding, {Key? key}) → Padding

Available on Widget, provided by the WidgetHelperExtensionMethods extension

padOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Padding

Available on Widget, provided by the WidgetHelperExtensionMethods extension

positioned({Key? key, double? left, double? top, double? right, double? bottom, double? width, double? height}) → Positioned

Available on Widget, provided by the WidgetHelperExtensionMethods extension

positionedFill({Key? key}) → Positioned

Available on Widget, provided by the WidgetHelperExtensionMethods extension

sizeTransition({AlignmentGeometry? alignment}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
transformScale({Key? key, double scale = 1.0, AlignmentGeometry alignment = Alignment.center}) → Transform

Available on Widget, provided by the WidgetHelperExtensionMethods extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited