HubbleBackgroundColor class

Inheritance

Constructors

HubbleBackgroundColor({required Color blue, required Color green, required Color orange, required Color purple, required Color yellow})
const

Properties

blue → Color
final
green → Color
final
hashCode → int
The hash code for this object.
no setterinherited
orange → Color
final
purple → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Object
The extension's type.
no setterinherited
yellow → Color
final

Methods

copyWith({Color? blue, Color? green, Color? orange, Color? purple, Color? yellow}) → ThemeExtension<HubbleBackgroundColor>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<HubbleBackgroundColor>? other, double t) → ThemeExtension<HubbleBackgroundColor>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited