HubbleButtonStyle class

Constructors

HubbleButtonStyle({required HubbleButtonStateVariant<Color> color, required BorderRadius radius, required HubbleButtonStateVariant<TextStyle> textStyle, required EdgeInsets padding, required double height, required HubbleButtonStateVariant<Border?> border, HubbleButtonStateVariant<Color> foregroundColor = const HubbleButtonStateVariant<Color>.all(Colors.transparent)})
HubbleButtonStyle.ghost({required HubbleColorPalette colors, required HubbleTypography typography})
factory
HubbleButtonStyle.solid({required HubbleColorPalette colors, required HubbleTypography typography})
factory

Properties

border → HubbleButtonStateVariant<Border?>
final
color → HubbleButtonStateVariant<Color>
final
foregroundColor → HubbleButtonStateVariant<Color>
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
padding → EdgeInsets
final
radius → BorderRadius
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → HubbleButtonStateVariant<TextStyle>
final

Methods

copyWith({HubbleButtonStateVariant<Color>? color, BorderRadius? radius, HubbleButtonStateVariant<TextStyle>? textStyle, EdgeInsets? padding, double? height, HubbleButtonStateVariant<Border>? border}) → HubbleButtonStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → HubbleButtonStyle