HubbleButtonStyleSizeVariants class

Constructors

HubbleButtonStyleSizeVariants({required HubbleButtonStyle small, required HubbleButtonStyle medium, required HubbleButtonStyle large})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
large → HubbleButtonStyle
final
medium → HubbleButtonStyle
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
small → HubbleButtonStyle
final

Methods

fromSize(HubbleButtonSize size) → HubbleButtonStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited