HubbleColorVariantClass class

Inheritance

Constructors

HubbleColorVariantClass({required HubbleColorVariants primary, required HubbleColorVariants secondary, required HubbleColorVariants tertiary})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
primary → HubbleColorVariants
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondary → HubbleColorVariants
final
tertiary → HubbleColorVariants
final
type → Object
The extension's type.
no setterinherited

Methods

copyWith({HubbleColorVariants? primary, HubbleColorVariants? secondary, HubbleColorVariants? tertiary}) → ThemeExtension<HubbleColorVariantClass>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<HubbleColorVariantClass>? other, double t) → ThemeExtension<HubbleColorVariantClass>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited