HubbleColorVariants class

Inheritance

Constructors

HubbleColorVariants({required Color light, required Color medium, required Color dark, required Color darkPlus})
const
HubbleColorVariants.all(Color color)
const

Properties

dark → Color
final
darkPlus → Color
final
hashCode → int
The hash code for this object.
no setterinherited
light → Color
final
medium → Color
final
normal → Color
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Object
The extension's type.
no setterinherited

Methods

copyWith({Color? light, Color? medium, Color? dark, Color? darkPlus}) → ThemeExtension<HubbleColorVariants>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<HubbleColorVariants>? other, double t) → ThemeExtension<HubbleColorVariants>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited