HubbleDeclaration class

Inheritance

Constructors

HubbleDeclaration({required String declarationText, bool isChecked = true, bool isMandatory = true})

Properties

allowProceeding → bool
no setter
declarationText ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether the bloc is closed.
no setterinherited
isMandatory ↔ bool
getter/setter pair
listable → ValueListenable<bool>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → SimpleValue<bool>
The current state.
no setterinherited
stream → Stream<SimpleValue<bool>>
The current stream of states.
no setterinherited
value ↔ bool
getter/setter pairinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
build(Widget builder(BuildContext context, bool value), {bool when(bool, bool)?}) → Widget
inherited
buildAs<Z>(Widget builder(BuildContext context, Z value), {bool when(bool, bool)?}) → Widget
inherited
buildIfNotEqual(Widget builder(BuildContext context, bool value)) → Widget
inherited
close() → Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
emit(SimpleValue<bool> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
fromContext(BuildContext context, {bool listen = true}) → SimpleValueCubit<bool>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<SimpleValue<bool>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
setValue(bool value) → void
inherited
switchValue() → void
toString() → String
A string representation of this object.
inherited
update(bool predicate(bool value)) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited