HubbleGradients class

Constructors

HubbleGradients({required Gradient primary, required Gradient secondary, required Gradient tertiary, required Gradient background})
const

Properties

background → Gradient
final
hashCode → int
The hash code for this object.
no setterinherited
primary → Gradient
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondary → Gradient
final
tertiary → Gradient
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited