HubbleRadioButtonVariants class

Constructors

HubbleRadioButtonVariants({required HubbleRadioStyle selected, required HubbleRadioStyle unselected})
const
HubbleRadioButtonVariants.light({required HubbleTypography typography, required HubbleSpaces spaces, required HubbleColorPalette colors})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → HubbleRadioStyle
final
unselected → HubbleRadioStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited