HubbleRadioStyle class

Constructors

HubbleRadioStyle({required double radioSize, required double radioBorderWidth, required Color radioColor, required Color radioBackground, required Color boxBackground, required TextStyle titleStyle, required TextStyle subtitleStyle})
const

Properties

boxBackground → Color
final
hashCode → int
The hash code for this object.
no setterinherited
radioBackground → Color
final
radioBorderWidth → double
final
radioColor → Color
final
radioSize → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleStyle → TextStyle
final
titleStyle → TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited