HubbleStateColors class

Inheritance

Constructors

HubbleStateColors({required HubbleColorVariants success, required HubbleColorVariants warning, required HubbleColorVariants error})
const

Properties

error → HubbleColorVariants
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → HubbleColorVariants
final
type → Object
The extension's type.
no setterinherited
warning → HubbleColorVariants
final

Methods

copyWith({HubbleColorVariants? success, HubbleColorVariants? warning, HubbleColorVariants? error}) → ThemeExtension<HubbleStateColors>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<HubbleStateColors>? other, double t) → ThemeExtension<HubbleStateColors>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited