HubbleSwitchStyle class

Constructors

HubbleSwitchStyle({required Color activeColor, required Color inactiveColor, required Color activeTrackColor, required Color inactiveTrackColor, required Color borderColor})
const
HubbleSwitchStyle.black()
HubbleSwitchStyle.dark(HubbleColorPalette colors)
HubbleSwitchStyle.light(HubbleColorPalette colors)

Properties

activeColor → Color
final
activeTrackColor → Color
final
borderColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveColor → Color
final
inactiveTrackColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited