HubbleViewModel<T extends HubbleViewState> class abstract

Inheritance
Implementers

Constructors

HubbleViewModel({T? data})

Properties

hashCode → int
The hash code for this object.
no setterinherited
initializer → DeferredJob<T>
latefinal
isClosed → bool
Whether the bloc is closed.
no setterinherited
isInitialized → bool
no setter
listable → ValueListenable<HubbleViewState>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snack → HubbleSnackBarState
no setter
state → SimpleValue<HubbleViewState>
The current state.
no setterinherited
stream → Stream<SimpleValue<HubbleViewState>>
The current stream of states.
no setterinherited
value ↔ HubbleViewState
getter/setter pairinherited
viewState → T
no setter

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
build(Widget builder(BuildContext context, HubbleViewState value), {bool when(HubbleViewState, HubbleViewState)?}) → Widget
inherited
buildAs<Z>(Widget builder(BuildContext context, Z value), {bool when(HubbleViewState, HubbleViewState)?}) → Widget
inherited
buildIfNotEqual(Widget builder(BuildContext context, HubbleViewState value)) → Widget
inherited
close() → Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
override
defer<X>(dynamic object, void callback(X object)) → void
deferredScrollController({bool keepScrollOffset = true, double initialScrollOffset = 0.0}) → ScrollController
deferStream(StreamSubscription subscription) → void
emit(SimpleValue<HubbleViewState> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
fromContext(BuildContext context, {bool listen = true}) → SimpleValueCubit<HubbleViewState>
inherited
hydrate() → Future<void>
hydrateHeadless() → Future<T>
init() → Future<T>
inject<Injectable extends Object>() → Injectable
maybePop({Object? result}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAfterInit() → void
onChange(Change<SimpleValue<HubbleViewState>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
onInitFailure() → void
reactive<F>(F initialValue) → SimpleValueCubit<F>
reInit() → void
setValue(HubbleViewState value) → void
inherited
showInModal<ModalResult>(WidgetBuilder builder, {required String routeName, Map<String, dynamic>? eventProps, bool expand = false}) → Future<ModalResult?>
softReInit() → Future<T>
toString() → String
A string representation of this object.
inherited
update(HubbleViewState predicate(HubbleViewState value)) → void
inherited
updateViewState(T predicate(T value)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited