ColorTransitionEffect class

Holds painting configuration to be used by TransitionPainter

Inheritance

Constructors

ColorTransitionEffect({double activeStrokeWidth = 1.5, double offset = 16.0, double dotWidth = 16.0, double dotHeight = 16.0, double spacing = 8.0, double radius = 16, Color dotColor = Colors.grey, Color activeDotColor = Colors.indigo, double strokeWidth = 1.0, PaintingStyle paintStyle = PaintingStyle.fill})
Default constructor
const

Properties

activeDotColor → Color
The active dot color
finalinherited
activeStrokeWidth → double
The active dot strokeWidth
final
dotColor → Color
Inactive dots color or all dots in some effects
finalinherited
dotHeight → double
Singe dot height
finalinherited
dotWidth → double
Singe dot width
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
paintStyle → PaintingStyle
Inactive dots paint style (fill|stroke) defaults to fill.
finalinherited
radius → double
Single dot radius
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
The horizontal space between dots
finalinherited
strokeWidth → double
This is ignored if paintStyle is PaintStyle.fill
finalinherited

Methods

buildPainter(int count, double offset) → IndicatorPainter
Builds a new painter every time the page offset changes
override
calculateSize(int count) → Size
Calculates the size of canvas based on dots count, size and spacing
inherited
hitTestDots(double dx, int count, double current) → int
Returns the index of the section that contains dx.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited