CustomizableEffect class

Holds painting configuration to be used by CustomizablePainter

Inheritance

Constructors

CustomizableEffect({required DotDecoration dotDecoration, required DotDecoration activeDotDecoration, ColorBuilder? activeColorOverride, double spacing = 8, ColorBuilder? inActiveColorOverride})
Default constructor
const

Properties

activeColorOverride → ColorBuilder?
Builds dynamic colors for active dot
final
activeDotDecoration → DotDecoration
Holds painting decoration for active dots
final
dotDecoration → DotDecoration
Holds painting decoration for inactive dots
final
hashCode → int
The hash code for this object.
no setterinherited
inActiveColorOverride → ColorBuilder?
Builds dynamic colors for inactive dots
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
The space between two dots
final

Methods

buildPainter(int count, double offset) → IndicatorPainter
Builds a new painter every time the page offset changes
override
calculateSize(int count) → Size
Calculates the size of canvas based on dots count, size and spacing
override
hitTestDots(double dx, int count, double current) → int
Returns the index of the section that contains dx.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited