DotBorder class

Holds dot-border painting specs

Constructors

DotBorder({double width = 1.0, Color color = Colors.black87, double padding = 0.0, DotBorderType type = DotBorderType.solid})
Default constructor
const

Properties

color → Color
The color of the border
final
hashCode → int
The hash code for this object.
no setterinherited
neededSpace → double
Calculates the needed gap based on type
no setter
padding → double
The padding between the dot and the border
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DotBorderType
The border variant
final
width → double
The thinness of the border line
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lerp(DotBorder a, DotBorder b, double t) → DotBorder
Lerps the value between active dot border and prev-active dot's border

Constants

none → const DotBorder
Builds an instance with type DotBorderType.none