DotDecoration class

Holds dot painting specs

Constructors

DotDecoration({BorderRadius borderRadius = BorderRadius.zero, Color color = Colors.white, DotBorder dotBorder = DotBorder.none, double verticalOffset = 0.0, double rotationAngle = 0.0, double width = 8, double height = 8})
Default constructor
const

Properties

borderRadius → BorderRadius
The border radius of the dot
final
color → Color
The color of the dot
final
dotBorder → DotBorder
The dotBorder configuration of the dot
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
the height of the dot
final
rotationAngle → double
The rotation angle of the dot
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalOffset → double
The vertical offset of the dot
final
width → double
The width of the dot
final

Methods

copyWith({BorderRadius? borderRadius, double? width, double? height, Color? color, DotBorder? dotBorder, double? verticalOffset, double? rotationAngle}) → DotDecoration
Builds a new instance with the given override values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lerp(DotDecoration a, DotDecoration b, double t) → DotDecoration
Lerps the value between active dot and prev-active dot