IndicatorEffect class abstract

An Abstraction for a dot-indicator animation effect

Constructors

IndicatorEffect()
Const constructor
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildPainter(int count, double offset) → IndicatorPainter
Builds a new painter every time the page offset changes
calculateSize(int count) → Size
Calculates the size of canvas based on dots count, size and spacing
hitTestDots(double dx, int count, double current) → int
Returns the index of the section that contains dx.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited