ScrollingDotsEffect class

Holds painting configuration to be used by ScrollingDotsPainter or ScrollingDotsWithFixedCenterPainter

Inheritance

Constructors

ScrollingDotsEffect({double activeStrokeWidth = 1.5, double activeDotScale = 1.3, double smallDotScale = 0.66, int maxVisibleDots = 5, bool fixedCenter = false, double offset = 16.0, double dotWidth = 16.0, double dotHeight = 16.0, double spacing = 8.0, double radius = 16, Color dotColor = Colors.grey, Color activeDotColor = Colors.indigo, double strokeWidth = 1.0, PaintingStyle paintStyle = PaintingStyle.fill})
Default constructor
const

Properties

activeDotColor → Color
The active dot color
finalinherited
activeDotScale → double
activeDotScale is multiplied by dotWidth to resolve active dot scaling
final
activeStrokeWidth → double
The active dot strokeWidth this is ignored if fixedCenter is false
final
dotColor → Color
Inactive dots color or all dots in some effects
finalinherited
dotHeight → double
Singe dot height
finalinherited
dotWidth → double
Singe dot width
finalinherited
fixedCenter → bool
if True the old center dot style will be used
final
hashCode → int
The hash code for this object.
no setterinherited
maxVisibleDots → int
The max number of dots to display at a time if count is <= maxVisibleDots maxVisibleDots = count must be an odd number that's >= 5
final
paintStyle → PaintingStyle
Inactive dots paint style (fill|stroke) defaults to fill.
finalinherited
radius → double
Single dot radius
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smallDotScale → double
smallDotScale is multiplied by dotWidth to resolve side dots
final
spacing → double
The horizontal space between dots
finalinherited
strokeWidth → double
This is ignored if paintStyle is PaintStyle.fill
finalinherited

Methods

buildPainter(int count, double offset) → BasicIndicatorPainter
Builds a new painter every time the page offset changes
override
calculateSize(int count) → Size
Calculates the size of canvas based on dots count, size and spacing
override
hitTestDots(double dx, int count, double current) → int
Returns the index of the section that contains dx.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited