HubbleBoxShadow class

Constructors

HubbleBoxShadow({required HubbleColor color, required Offset offset, required double blurRadius, required double spreadRadius})

Properties

blurRadius → double
final
boxShadow ↔ BoxShadow
getter/setter pair
color → HubbleColor
final
hashCode → int
The hash code for this object.
no setterinherited
offset → Offset
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spreadRadius → double
final

Methods

applyTheme(HubbleThemeData theme) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited