HubbleTextStyle class

Constructors

HubbleTextStyle({required TextStyle base, required HubbleColor? color, required HubbleColor? backgroundColor, required HubbleColor? decorationColor, required List<HubbleTextShadow>? shadow, required HubbleGradient? foregroundGradient, required HubbleGradient? backgroundGradient})

Properties

backgroundColor → HubbleColor?
final
backgroundGradient → HubbleGradient?
final
base → TextStyle
final
color → HubbleColor?
final
decorationColor → HubbleColor?
final
foregroundGradient → HubbleGradient?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → List<HubbleTextShadow>?
final
textStyle ↔ TextStyle
getter/setter pair

Methods

applyTheme(HubbleThemeData theme) → void
foreground() → Paint?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited