SimpleHeaderDelegate class

Inheritance

Constructors

SimpleHeaderDelegate(Widget child, Widget floatingChild, {double minHeight = 0, double maxHeight = 0, bool isSimple = false})

Properties

child → Widget
final
floatingChild → Widget
final
halfHeight → double
latefinal
hashCode → int
The hash code for this object.
no setterinherited
isSimple → bool
final
maxExtent → double
The size of the header when it is not shrinking at the top of the viewport.
no setteroverride
maxHeight → double
final
minExtent → double
The smallest size to allow the header to reach, when it shrinks at the start of the viewport.
no setteroverride
minHeight → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showOnScreenConfiguration → PersistentHeaderShowOnScreenConfiguration?
Specifies how floating headers and pinned headers should behave in response to RenderObject.showOnScreen calls.
no setterinherited
snapConfiguration → FloatingHeaderSnapConfiguration?
Specifies how floating headers should animate in and out of view.
no setterinherited
stretchConfiguration → OverScrollHeaderStretchConfiguration?
Specifies an AsyncCallback and offset for execution.
no setterinherited
vsync → TickerProvider?
A TickerProvider to use when animating the header's size changes.
no setterinherited

Methods

animationWrapper(Widget child) → Widget
build(BuildContext context, double shrinkOffset, bool overlapsContent) → Widget
The widget to place inside the SliverPersistentHeader.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant SliverPersistentHeaderDelegate oldDelegate) → bool
Whether this delegate is meaningfully different from the old delegate.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited