WidgetRepository class

Constructors

WidgetRepository()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nativeWidgets → Map<String, NativeWidgetBuilder>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

merge(Map<String, NativeWidgetBuilder> widgets) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(String name, NativeWidgetBuilder builder) → void
registerNativeWidget(String name, NativeWidgetBuilder builder) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited