XAnimatedOpacityParams class

Inheritance

Constructors

XAnimatedOpacityParams({required double opacity, required Duration duration, required Curve curve, required SSRWidget child})

Properties

child SSRWidget
getter/setter pair
curve Curve
getter/setter pair
duration Duration
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
opacity double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(XAnimatedOpacity widget, SSRBuildContext context, WidgetMetadata metadata) XAnimatedOpacityParams?