XBoxParams class

Inheritance

Constructors

XBoxParams({Key? key, required SSRWidget? child, required double? width, required double? height, required EdgeInsets? padding, required EdgeInsets? margin, HubbleColor? color, required XAssetParams? backgroundImage, required BorderRadius? radius, required HubbleBorder? border, required List<HubbleBoxShadow> shadow, required HubbleGradient? gradient, required Clip clip, required AlignmentGeometry? alignment})
const

Properties

alignment → AlignmentGeometry?
final
backgroundImage → XAssetParams?
final
border → HubbleBorder?
final
child → SSRWidget?
final
clip → Clip
final
color → HubbleColor?
final
gradient → HubbleGradient?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
finalinherited
margin → EdgeInsets?
final
padding → EdgeInsets?
final
radius → BorderRadius?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → List<HubbleBoxShadow>
final
width → double?
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XBox widget, SSRBuildContext context, WidgetMetadata metadata) → XBoxParams?