XButtonParams class

Inheritance

Constructors

XButtonParams({required SSRWidget child, required XEventTriggerBase? onPressed, required HubbleButtonState state, double? width, double? height, HubbleButtonSize size = HubbleButtonSize.medium, bool isGhost = false, bool isOutlined = false, ButtonTapEvent? tapEvent})

Properties

child → SSRWidget
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
isGhost → bool
final
isOutlined → bool
final
key → Key?
finalinherited
onPressed → XEventTriggerBase?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → HubbleButtonSize
final
state → HubbleButtonState
final
tapEvent → ButtonTapEvent?
final
width → double?
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XButton widget, SSRBuildContext context) → XButtonParams