XColumnParams class

Inheritance

Constructors

XColumnParams({required MainAxisAlignment mainAxisAlignment, required MainAxisSize mainAxisSize, required CrossAxisAlignment crossAxisAlignment, required VerticalDirection verticalDirection, TextDirection? textDirection, TextBaseline? textBaseline, required List<SSRWidget> children})

Properties

children → List<SSRWidget>
final
crossAxisAlignment → CrossAxisAlignment
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
mainAxisAlignment → MainAxisAlignment
final
mainAxisSize → MainAxisSize
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textBaseline → TextBaseline?
final
textDirection → TextDirection?
final
verticalDirection → VerticalDirection
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XColumn widget, SSRBuildContext context, WidgetMetadata metadata) → XColumnParams?