XCustomScrollViewParams class

Inheritance

Constructors

XCustomScrollViewParams({required List<SSRWidget> slivers, required Axis scrollDirection, required Clip clipBehavior, required String restorationId, required bool shrinkWrap, required int semanticChildCount, required double cacheExtent, required bool reverse, required bool primary})

Properties

cacheExtent → double
final
clipBehavior → Clip
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
primary → bool
final
restorationId → String
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
final
semanticChildCount → int
final
shrinkWrap → bool
final
slivers → List<SSRWidget>
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XCustomScrollView widget, SSRBuildContext context, WidgetMetadata metadata) → XCustomScrollViewParams?