XDividerParams class

Inheritance

Constructors

XDividerParams({double? height, double? thickness, double? indent, double? endIndent, HubbleColor? color})

Properties

color → HubbleColor?
final
endIndent → double?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
indent → double?
final
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double?
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XDivider widget, SSRBuildContext context) → XDividerParams?