XEventTriggerBase class abstract

Implementers

Constructors

XEventTriggerBase()

Properties

contextHandler → void Function(BuildContext)
no setter
eventArgs ↔ Map<String, dynamic>
latefinal
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailing → List<XEventTriggerBase?>
final

Methods

applyTheme(HubbleThemeData theme) → void
call(BuildContext context) → void
handler(BuildContext context) → VoidCallback
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XEventTrigger trigger, SSRBuildContext context) → XEventTriggerBase?