XFormSubmitTrigger class

Inheritance

Constructors

XFormSubmitTrigger({required String formId})
XFormSubmitTrigger.from(XEventTrigger_FormSubmit formSubmit)
factory

Properties

contextHandler → void Function(BuildContext)
no setterinherited
eventArgs ↔ Map<String, dynamic>
latefinalinherited
formId → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailing → List<XEventTriggerBase?>
finalinherited

Methods

applyTheme(HubbleThemeData theme) → Future<void>
override
call(BuildContext context) → void
override
handler(BuildContext context) → VoidCallback
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited