XIconParams class

Inheritance

Constructors

XIconParams({required IconData iconData, HubbleColor? color, double? size, List<XIconShadowParams>? shadows})

Properties

color → HubbleColor?
final
hashCode → int
The hash code for this object.
no setterinherited
iconData → IconData
final
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → List<XIconShadowParams>?
final
size → double?
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildIconData(XIcon icon) → IconData
from(XIcon widget, SSRBuildContext context) → XIconParams?