XIconShadowParams class

Constructors

XIconShadowParams({required double blurRadius, required Offset offset, required HubbleColor color})
XIconShadowParams.from(XIconShadow shadow)
factory

Properties

blurRadius → double
final
color → HubbleColor
final
hashCode → int
The hash code for this object.
no setterinherited
offset → Offset
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited