XIndicatorWrappings class

Inheritance

Constructors

XIndicatorWrappings({required XIndicatorBuilder? indicator, required EdgeInsets? padding, required Alignment? alignment})
XIndicatorWrappings.from(XHorizontalScroll widget)
factory

Properties

alignment → Alignment?
final
hashCode → int
The hash code for this object.
no setterinherited
hasIndicator → bool
no setter
indicator → XIndicatorBuilder?
final
key → Key?
finalinherited
padding → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context, {PageController? controller, int itemCount = 0}) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited