XMarqueeParams class

Inheritance

Constructors

XMarqueeParams({required String text, required Border border, required double? height, required HubbleTextStyle style})

Properties

border Border
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style HubbleTextStyle
final
text String
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(XMarquee widget, SSRBuildContext context) XMarqueeParams?