XOpenModalTrigger class

Inheritance

Constructors

XOpenModalTrigger({SSRWidget? child, required String pageName, required Symbol contextName})
XOpenModalTrigger.from(XEventTrigger_OpenModal openModal, SSRBuildContext context)
factory

Properties

child → SSRWidget?
final
contextHandler → void Function(BuildContext)
no setterinherited
contextName → Symbol
final
eventArgs ↔ Map<String, dynamic>
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
pageName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailing → List<XEventTriggerBase?>
finalinherited

Methods

applyTheme(HubbleThemeData theme) → void
override
call(BuildContext context) → void
override
handler(BuildContext context) → VoidCallback
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited