XScaleParams class

Inheritance

Constructors

XScaleParams({required SSRWidget child, required double scale, Offset? origin})

Properties

child → SSRWidget
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
origin → Offset?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XScale widget, SSRBuildContext context, WidgetMetadata metadata) → XScaleParams?