XSemanticsParams class

Inheritance

Constructors

XSemanticsParams({required bool? explicitChildNodes, required bool? excludeSemantics, required bool? enabled, required bool? checked, required bool? selected, required bool? toggled, required bool? button, required bool? header, required bool? textField, required bool? readOnly, required bool? focusable, required bool? focused, required bool? inMutuallyExclusiveGroup, required bool? obscured, required bool? multiline, required bool? scopesRoute, required bool? namesRoute, required bool? hidden, required bool? image, required bool? liveRegion, required int? maxValueLength, required int? currentValueLength, required String? label, required String? hint, required String? value, required String? increasedValue, required String? decreasedValue, required String? onTapHint, required String? onLongPressHint, required SSRWidget? child})

Properties

button → bool?
final
checked → bool?
final
child → SSRWidget?
final
currentValueLength → int?
final
decreasedValue → String?
final
enabled → bool?
final
excludeSemantics → bool?
final
explicitChildNodes → bool?
final
focusable → bool?
final
focused → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
final
hidden → bool?
final
hint → String?
final
image → bool?
final
increasedValue → String?
final
inMutuallyExclusiveGroup → bool?
final
key → Key?
finalinherited
label → String?
final
liveRegion → bool?
final
maxValueLength → int?
final
multiline → bool?
final
namesRoute → bool?
final
obscured → bool?
final
onLongPressHint → String?
final
onTapHint → String?
final
readOnly → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopesRoute → bool?
final
selected → bool?
final
textField → bool?
final
toggled → bool?
final
value → String?
final

Methods

applyTheme(HubbleThemeData theme) → Future<void>
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XSemantics widget, SSRBuildContext context, WidgetMetadata metadata) → XSemanticsParams?