XSliverPersistentWidgetParams class

Inheritance

Constructors

XSliverPersistentWidgetParams({required SSRWidget child, required double minExtent, required double maxExtent, SSRWidget? floatingChild, bool isSimple = false, bool isPinned = false, bool isFloating = false})

Properties

child → SSRWidget
final
floatingChild → SSRWidget?
final
hashCode → int
The hash code for this object.
no setterinherited
isFloating → bool
final
isPinned → bool
final
isSimple → bool
final
key → Key?
finalinherited
maxExtent → double
final
minExtent → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XSliverPersistentWidget widget, SSRBuildContext context) → XSliverPersistentWidgetParams?