XSnackBarTrigger class

Inheritance

Constructors

XSnackBarTrigger({required String title, required String message, required XSnackBarType type})
XSnackBarTrigger.from(XEventTrigger_ShowSnackBar showSnackBar)
factory

Properties

contextHandler → void Function(BuildContext)
no setterinherited
eventArgs ↔ Map<String, dynamic>
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
trailing → List<XEventTriggerBase?>
finalinherited
type → XSnackBarType
final

Methods

applyTheme(HubbleThemeData theme) → Future<void>
override
call(BuildContext context) → void
override
handler(BuildContext context) → VoidCallback
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited