XSpacerParams class

Inheritance

Constructors

XSpacerParams({required double? width, required double? height, SSRWidget? child, bool isSpacer = false})

Properties

child SSRWidget?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pair
isSpacer bool
getter/setter pair
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
getter/setter pair

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(XSpacer widget, SSRBuildContext context, WidgetMetadata metadata) XSpacerParams?