XStackParams class

Inheritance

Constructors

XStackParams({required List<SSRWidget> children, AlignmentGeometry? alignment, required StackFit fit, required Clip clipBehavior, TextDirection? textDirection, bool isSliver = false})

Properties

alignment → AlignmentGeometry?
final
children → List<SSRWidget>
final
clipBehavior → Clip
final
fit → StackFit
final
hashCode → int
The hash code for this object.
no setterinherited
isSliver → bool
final
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection → TextDirection?
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XStack widget, SSRBuildContext context, WidgetMetadata metadata) → XStackParams?