XSwitchNumConditionParams class

Inheritance

Constructors

XSwitchNumConditionParams({required double value, required XNumOperator operator, required double compareValue})
const
XSwitchNumConditionParams.fromXProto(XSwitchCase_NumCondition xProto, dynamic value)
factory

Properties

compareValue → double
final
hashCode → int
The hash code for this object.
no setterinherited
operator → XNumOperator
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
final

Methods

isMatched() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited