XTextParams class

Inheritance

Constructors

XTextParams({required String data, required HubbleTextStyle style, TextAlign? textAlign, int? maxLines = 1, TextOverflow? overflow, bool isReactive = false, required Symbol contextName, bool isInterpolated = false, XEventTriggerBase? onTap})

Properties

contextName → Symbol
final
data ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isInterpolated → bool
final
isReactive → bool
final
key → Key?
finalinherited
maxLines → int?
final
onTap → XEventTriggerBase?
final
overflow → TextOverflow?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → HubbleTextStyle
final
textAlign → TextAlign?
final

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XText widget, SSRBuildContext context) → XTextParams