XTransformParams class

Inheritance

Constructors

XTransformParams({required SSRWidget child, Matrix4? matrix4, Offset? origin})

Properties

child → SSRWidget
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
matrix4 → Matrix4?
final
origin → Offset?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(XTransform widget, SSRBuildContext context, WidgetMetadata metadata) → XTransformParams?