XWidgetCacheParams class

Inheritance

Constructors

XWidgetCacheParams({required SSRWidget child})
XWidgetCacheParams.from(XWidgetCache widget, SSRBuildContext context)
factory

Properties

child → SSRWidget
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyTheme(HubbleThemeData theme) → void
override
build(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited