HubbleButtonLargeStyle class

Constructors

HubbleButtonLargeStyle({required ButtonStyle buttonStyle, required Color color, required Color disabledColor, required double? width, required double? height, required double radius, required TextStyle textStyle, required TextStyle disabledTextStyle, Color? loaderColor, EdgeInsets? padding})

Properties

buttonStyle → ButtonStyle
final
color → Color
final
disabledColor → Color
final
disabledTextStyle → TextStyle
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
loaderColor → Color?
final
padding → EdgeInsets?
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle
final
width → double?
final

Methods

copyWith({Color? color, Color? disabledColor, double? height, double? width, double? radius, TextStyle? textStyle, TextStyle? disabledTextStyle, ButtonStyle? buttonStyle}) → HubbleButtonLargeStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultStyle({TextStyle? textStyle, Color? color}) → HubbleButtonLargeStyle
of(BuildContext context) → HubbleButtonLargeStyle