CustomStatefulAnimationBuilder class

Inheritance
Available extensions

Constructors

CustomStatefulAnimationBuilder({Key? key, required Widget builder(BuildContext, double value), Duration duration = const Duration(milliseconds: 500), int repeatCount = 0, Curve curve = Curves.linear, VoidCallback? onFinished, AnimationController? controller, bool reverse = false})
const

Properties

builder → Widget Function(BuildContext, double value)
final
controller → AnimationController?
final
curve → Curve
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onFinished → VoidCallback?
final
repeatCount → int
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

center({Key? key}) → Center

Available on Widget, provided by the WidgetHelperExtensionMethods extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomStatefulAnimationBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
enlarge() → Transform

Available on Widget, provided by the WidgetHelperExtensionMethods extension

expanded({Key? key, int flex = 1}) → Expanded

Available on Widget, provided by the WidgetHelperExtensionMethods extension

fadeInSlideUp({int? nextRunDelay, AnimationIntervalController? intervalController}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

hubbleAnimate({int? nextRunDelay, AnimationIntervalController? intervalController, List<Effect>? effects}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pad(EdgeInsetsGeometry padding, {Key? key}) → Padding

Available on Widget, provided by the WidgetHelperExtensionMethods extension

padOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Padding

Available on Widget, provided by the WidgetHelperExtensionMethods extension

positioned({Key? key, double? left, double? top, double? right, double? bottom, double? width, double? height}) → Positioned

Available on Widget, provided by the WidgetHelperExtensionMethods extension

positionedFill({Key? key}) → Positioned

Available on Widget, provided by the WidgetHelperExtensionMethods extension

sizeTransition({AlignmentGeometry? alignment}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
transformScale({Key? key, double scale = 1.0, AlignmentGeometry alignment = Alignment.center}) → Transform

Available on Widget, provided by the WidgetHelperExtensionMethods extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited