ErrorMessageBoxStyle class

Constructors

ErrorMessageBoxStyle({required BorderRadiusGeometry borderRadius, required TextStyle textStyle, required BoxBorder errorBorder, required EdgeInsetsGeometry padding})

Properties

borderRadius ↔ BorderRadiusGeometry
getter/setter pair
errorBorder ↔ BoxBorder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
padding ↔ EdgeInsetsGeometry
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle ↔ TextStyle
getter/setter pair

Methods

copy({BoxBorder? errorBorder, TextStyle? textStyle, BorderRadiusGeometry? borderRadius, EdgeInsetsGeometry? padding}) → ErrorMessageBoxStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

light() → ErrorMessageBoxStyle
of(BuildContext context) → ErrorMessageBoxStyle