GoalProgressBoxesStyle class

Constructors

GoalProgressBoxesStyle()

Properties

hashCode → int
The hash code for this object.
no setterinherited
paidTabletColor ↔ Color
getter/setter pair
redeemedTablet ↔ Color
getter/setter pair
rewardTabletGradient ↔ LinearGradient
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabletHeight ↔ double
getter/setter pair
tabletRadius ↔ BorderRadius
getter/setter pair
unpaidTablet ↔ Color
getter/setter pair

Methods

copyWith({Color? paidColor, Color? unpaidColor}) → GoalProgressBoxesStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited