HubblePageControllerState<T extends StatefulWidget> class abstract

extend this abstract class for building page views this class includes functions like

  • goToNextPage()
  • goToPreviousPage()
  • back button handlers: onPressAppBarBackButton(), onWillPop() for device back button

SimpleValueCubit

See kyc flow for implementation

Inheritance

Constructors

HubblePageControllerState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controller → PageController
final
hashCode → int
The hash code for this object.
no setterinherited
isUserOnTheFirstPage → bool
no setter
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
progress → SimpleValueCubit<double>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
goToNextPage() → void
goToPreviousPage() → void
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPressAppBarBackButton(BuildContext context) → void
call this method when back button present on the appbar of page view is pressed
onScrollEndNotificationReceived() → void
call this method when a scroll end notification is received from notification listener widget
onWillPop() → Future<bool>
call this when user presses the back button present within device controls
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited