HubbleSnackBar class

Constructors

HubbleSnackBar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

error({required OverlayState overlayState, required String title, required String message}) OverlayEntry
info({required OverlayState overlayState, required String title, required String message}) OverlayEntry
of(BuildContext context) HubbleSnackBarState
showSnackBar(OverlayState overlayState, {required String title, required String message, required Color borderColor, required Color backgroundColor, required Color textColor, required Widget icon}) OverlayEntry
success({required OverlayState overlayState, required String title, required String message}) OverlayEntry
warning({required OverlayState overlayState, required String title, required String message}) OverlayEntry