HubbleToastState class
Constructors
- HubbleToastState(OverlayState overlayState)
- HubbleToastState.of(BuildContext context)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- overlayState → OverlayState
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
warn(
{required String msg}) → OverlayEntry
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited