PointsRowItem class

Constructors

PointsRowItem({required WidgetBuilder textBuilder, Gradient? pointGradient, Color? pointColor, bool defaultGradient = false, double gap = 0, int flex = 1})

Properties

defaultGradient → bool
final
flex → int
final
gap → double
final
hashCode → int
The hash code for this object.
no setterinherited
pointColor → Color?
final
pointGradient → Gradient?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textBuilder → WidgetBuilder
final

Methods

build(BuildContext context, {required double pointSize, required double pointTopPadding, required double textGap}) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited