SheetMenuBuilder class

Constructors

SheetMenuBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ Widget?
getter/setter pair

Methods

addItem({required Widget icon, required String text, void onClick()?}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reveal(BuildContext context, {required RouteSettings settings, required SheetMenuStyle style}) → Future
setTitle(Widget title) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited