ShimmerContainer class

Inheritance
Available extensions

Constructors

ShimmerContainer({Key? key, Widget? child, Color color = Colors.black, Duration duration = const Duration(seconds: 1), BoxDecoration? decoration, Color movingColor = Colors.white, double? height, double? width, bool oneTimeOnly = false, BoxConstraints? constraints, EdgeInsets? padding, EdgeInsets? margin, bool isEnabled = true, Alignment? alignment})
const

Properties

alignment → Alignment?
final
child → Widget?
final
color → Color
final
constraints → BoxConstraints?
final
decoration → BoxDecoration?
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
isEnabled → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsets?
final
movingColor → Color
final
oneTimeOnly → bool
final
padding → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

center({Key? key}) → Center

Available on Widget, provided by the WidgetHelperExtensionMethods extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ShimmerContainer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
enlarge() → Transform

Available on Widget, provided by the WidgetHelperExtensionMethods extension

expanded({Key? key, int flex = 1}) → Expanded

Available on Widget, provided by the WidgetHelperExtensionMethods extension

fadeInSlideUp({int? nextRunDelay, AnimationIntervalController? intervalController}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

hubbleAnimate({int? nextRunDelay, AnimationIntervalController? intervalController, List<Effect>? effects}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pad(EdgeInsetsGeometry padding, {Key? key}) → Padding

Available on Widget, provided by the WidgetHelperExtensionMethods extension

padOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Padding

Available on Widget, provided by the WidgetHelperExtensionMethods extension

positioned({Key? key, double? left, double? top, double? right, double? bottom, double? width, double? height}) → Positioned

Available on Widget, provided by the WidgetHelperExtensionMethods extension

positionedFill({Key? key}) → Positioned

Available on Widget, provided by the WidgetHelperExtensionMethods extension

sizeTransition({AlignmentGeometry? alignment}) → Widget

Available on Widget, provided by the WidgetHelperExtensionMethods extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
transformScale({Key? key, double scale = 1.0, AlignmentGeometry alignment = Alignment.center}) → Transform

Available on Widget, provided by the WidgetHelperExtensionMethods extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited