RenderedPageContextState class

Inheritance

Constructors

RenderedPageContextState({IWidgetsRepo? repo, String? customBaseUrl})

Properties

customBaseUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
listable ValueListenable
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state SimpleValue
The current state.
no setterinherited
stream Stream<SimpleValue>
The current stream of states.
no setterinherited
value ↔ dynamic
getter/setter pairinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
build(Widget builder(BuildContext context, dynamic value), {bool when(dynamic, dynamic)?}) Widget
inherited
buildAs<Z>(Widget builder(BuildContext context, Z value), {bool when(dynamic, dynamic)?}) Widget
inherited
buildIfNotEqual(Widget builder(BuildContext context, dynamic value)) Widget
inherited
clear() → void
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
override
emit(SimpleValue state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
fromContext(BuildContext context, {bool listen = true}) SimpleValueCubit
inherited
getContext(String contextId) Map<String, String>
getContextLoader(String contextId) DeferredJob<XWidget>
getForm(String formId) Form
getWidgetLoader({required String widgetId, required Map<String, String> params, required String contextKey}) DeferredJob<XWidget>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<SimpleValue> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
setValue(dynamic value) → void
inherited
toString() String
A string representation of this object.
inherited
update(dynamic predicate(dynamic value)) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getModel<T extends ChangeNotifier>(BuildContext context, {required T build()}) → T?
of(BuildContext context) RenderedPageContextState