ValidatedFieldState class

Constructors

ValidatedFieldState({String value = '', String errorMessage = '', ValidatedFieldStatus status = ValidatedFieldStatus.noError, required String validator(String value), TextEditingController? controller})

Properties

controller → TextEditingController?
final
errorMessage → String
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
isInvalid → bool
no setter
isValid → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ValidatedFieldStatus
final
validator → String Function(String value)
final
value → String
final

Methods

copyIconBorder({String? value, required String errorMessage}) → ValidatedFieldState
copyWith({String? value, String? errorMessage, ValidatedFieldStatus? status, bool? isFocused, TextEditingController? controller}) → ValidatedFieldState
isFatalError() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited