XSliverAppBarParams class
Constructors
-
XSliverAppBarParams({required List<
SSRWidget> actions, SSRWidget? leading, SSRWidget? title, SSRWidget? flexibleSpace, double? elevation, double? scrolledUnderElevation, HubbleColor? shadowColor, HubbleColor? surfaceTintColor, HubbleColor? backgroundColor, HubbleColor? foregroundColor, bool? centerTitle, double? titleSpacing, double? collapsedHeight, double? expandedHeight, double? leadingWidth, HubbleColor? statusBarColor, required bool automaticallyImplyLeading, required bool forceElevated, required bool primary, required bool excludeHeaderSemantics, required bool floating, required bool pinned, required bool snap, required bool stretch, required double stretchTriggerOffset, required double toolbarHeight, required bool isExtended})
Properties
-
actions
→ List<
SSRWidget> -
final
- automaticallyImplyLeading → bool
-
final
- backgroundColor → HubbleColor?
-
final
- centerTitle → bool?
-
final
- collapsedHeight → double?
-
final
- elevation → double?
-
final
- excludeHeaderSemantics → bool
-
final
- expandedHeight → double?
-
final
- flexibleSpace → SSRWidget?
-
final
- floating → bool
-
final
- forceElevated → bool
-
final
- foregroundColor → HubbleColor?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExtended → bool
-
final
- key → Key?
-
finalinherited
- leading → SSRWidget?
-
final
- leadingWidth → double?
-
final
- pinned → bool
-
final
- primary → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrolledUnderElevation → double?
-
final
- shadowColor → HubbleColor?
-
final
- snap → bool
-
final
- statusBarColor → HubbleColor?
-
final
- stretch → bool
-
final
- stretchTriggerOffset → double
-
final
- surfaceTintColor → HubbleColor?
-
final
- title → SSRWidget?
-
final
- titleSpacing → double?
-
final
- toolbarHeight → double
-
final
Methods
-
applyTheme(
HubbleThemeData theme) → void -
override
-
build(
BuildContext context) → Widget -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
from(
XSliverAppBar widget, SSRBuildContext context, WidgetMetadata metadata) → XSliverAppBarParams?