HubbleSnackBarState class
Constructors
- HubbleSnackBarState(OverlayState overlayState)
- HubbleSnackBarState.of(BuildContext context)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- overlayState → OverlayState
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
error(
{required String title, required String message, double bottomOffset = 50}) → OverlayEntry -
errorWithResult(
JobResult result) → OverlayEntry -
info(
{required String title, required String message}) → OverlayEntry -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
success(
{required String title, required String message, double bottomOffset = 50}) → OverlayEntry -
toString(
) → String -
A string representation of this object.
inherited
-
warning(
{required String title, required String message, double bottomOffset = 50}) → OverlayEntry
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited